summaryrefslogtreecommitdiffstats
path: root/os-plugins/plugins/vmware/OpenSLX/Distro/Base.pm
diff options
context:
space:
mode:
Diffstat (limited to 'os-plugins/plugins/vmware/OpenSLX/Distro/Base.pm')
-rw-r--r--os-plugins/plugins/vmware/OpenSLX/Distro/Base.pm26
1 files changed, 18 insertions, 8 deletions
diff --git a/os-plugins/plugins/vmware/OpenSLX/Distro/Base.pm b/os-plugins/plugins/vmware/OpenSLX/Distro/Base.pm
index 2dfc2700..20769ca4 100644
--- a/os-plugins/plugins/vmware/OpenSLX/Distro/Base.pm
+++ b/os-plugins/plugins/vmware/OpenSLX/Distro/Base.pm
@@ -36,7 +36,7 @@ sub initialize
{
my $self = shift;
my $engine = shift;
-
+
return 1;
}
@@ -53,7 +53,7 @@ sub fillRunlevelScript
# Copyright 1998-2007 VMware, Inc. All rights reserved.
#
# This script manages the services needed to run VMware software
-
+
# Basic support for the Linux Standard Base Specification 1.3
### BEGIN INIT INFO
# Provides: VMware
@@ -65,10 +65,19 @@ sub fillRunlevelScript
# Description: Manages the services needed to run VMware software
### END INIT INFO
load_modules() {
- # to be filled in via the stage1 configuration script
- modprobe -qa vmmon vmnet vmblock 2>/dev/null || echo "Problem here!"
- # most probably nobody wants to run the parallel port driver ...
- #modprobe vm...
+ if [ \${vmware_kind} = "local" ]; then
+ # to be filled in via the stage1 configuration script
+ modprobe -qa vmmon vmnet vmblock 2>/dev/null || return 1
+ # most probably nobody wants to run the parallel port driver ...
+ #modprobe vm...
+ else
+ # load module manuall
+ vmware_kind_path=/opt/openslx/plugin-repo/vmware/\${vmware_kind}/
+ module_src_path=\${vmware_kind_path}/root/lib/vmware/modules/source
+ insmod \${module_src_path}/vmblock.o
+ insmod \${module_src_path}/vmmon.o
+ insmod \${module_src_path}/vmnet.o
+ fi
}
unload_modules() {
# to be filled with the proper list within via the stage1 configuration
@@ -135,8 +144,9 @@ sub fillRunlevelScript
echo "Stopping vmware background services ..."
killall vmnet-netifup vmnet-natd vmnet-bridge vmware vmplayer \\
vmware-tray vmnet-dhcpd 2>/dev/null
- # wait for shutting down of interfaces
- usleep 50000
+ # wait for shutting down of interfaces... vmnet needs kinda
+ # long
+ usleep 500000
unload_modules
;;
#status)